import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"

from mandaw.main import Mandaw
from mandaw.gameobject import GameObject
from mandaw.line import Line
from mandaw.color import Color
from mandaw.sprite import Sprite
from mandaw.text import Text



import pygame

class Mandaw:
    def __init__(self, title = "Mandaw", width = 800, height = 600, bg_color = "black"):
        self.width = width
        self.height = height
        self.title = title
        self.bg_color = bg_color

        pygame.init()
        self.clock = pygame.time.Clock()

        self.window = pygame.display.set_mode((self.width, self.height))
        pygame.display.set_caption(self.title)
        self.window.fill(self.bg_color)

        self.keys = pygame.key.get_pressed()

        self.UP = pygame.K_UP
        self.DOWN = pygame.K_DOWN
        self.LEFT = pygame.K_LEFT
        self.RIGHT = pygame.K_RIGHT
        
        self.W = pygame.K_w
        self.A = pygame.K_a
        self.S = pygame.K_s
        self.D = pygame.K_d

        self.SPACE = pygame.K_SPACE

    def run(self):
        pygame.display.flip()
        self.clock.tick(60)

        pygame.display.update()

        self.keys = pygame.key.get_pressed()

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                quit()

        self.window.fill(self.bg_color)



import pygame

class GameObject(pygame.Rect):
    def __init__(self, window, shape = "rect", width = 20, height = 20, x = 0, y = 0, color = "white"):
        self.x = x
        self.y = y
        self.shape = shape
        self.width = width
        self.height = height

        self.window = window
        self.color = color

    def draw(self):
        if self.shape == "rect" or self.shape == "rectangle":
            pygame.draw.rect(self.window.window, self.color, self)
        
        elif self.shape == "ellipse" or self.shape == "circle":
            pygame.draw.ellipse(self.window.window, self.color, self)
    
    def center(self):
        self.x = self.window.width / 2 - self.width / 2
        self.y = self.window.height / 2 - self.height / 2

if __name__ == "__main__":
    from mandaw import *

    mandaw = Mandaw()

    demo = GameObject(mandaw, shape = "ellipse", width = 20, height = 20, x = 0, y = 0, color = "red")
    demo.center()

    while True:
        demo.draw()
        mandaw.run()



import pygame

class Sprite:
    def __init__(self, window, image, x, y):
        self.image = pygame.image.load(image)
        self.window = window

        self.x = x
        self.y = y

    def draw(self):
        self.window.window.blit(self.image, (self.x, self.y))

    def get_width(self):
        return self.image.get_width()

    def get_height(self):
        return self.image.get_height()